function res=lognormal(r,rm,sigm)
% log-normal size distribution, which is normalozed to 1
% <r^n>=N*rm^n*exp(0.5*n^2*(log(sigm))^2)    n-moment of distribution
% reff=rm*exp(5/2*(log(sigm))^2)
% rmax=rm*exp(-(log(sigm))^2)=rm*(reff/rm)^-0.4
% input :
%        r - radius 
%        rm - is modal radia
%        sigm - sig of this distribution


res=1./(r*sqrt(2*pi)*log(sigm)).*exp(-0.5*(log(r/rm)/log(sigm)).^2);

